%define _buildid .0

%define aws_product_name_env  AWS_CLOUDWATCH_HOME
%define aws_product_name      mon

Summary:   The Command Line Tool serves as the client interface to the Amazon CloudWatch web service. Use this tool to monitor, manage, and publish Amazon CloudWatch metrics, as well as configure alarm actions based on data from metrics. 
Name:      aws-apitools-%{aws_product_name}
Version:   1.0.20.0
Release: 1%{?_buildid}%{?dist}
License:   Amazon Software License
Group:     Amazon/Tools
# http://aws.amazon.com/developertools/2534
URL:       http://aws.amazon.com/cloudwatch
Source0:   %{name}-%{version}.zip
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
Prefix:    /opt
Vendor:    Amazon AWS
Requires:  coreutils
Requires:  jre >= 1.6.0
Requires:  aws-apitools-common
BuildRequires: dos2unix

%define aws_path              %{prefix}/aws
%define aws_bin_path          %{aws_path}/bin
%define aws_product_name_v    %{aws_product_name}-%{version}
%define aws_product_path      %{aws_path}/apitools/%{aws_product_name_v}
%define aws_product_path_link %{aws_path}/apitools/%{aws_product_name}

%description
Amazon CloudWatch provides monitoring for AWS cloud resources and the applications customers run on AWS. Developers and system administrators can use it to collect and track metrics, gain insight, and react immediately to keep their applications and businesses running smoothly. Amazon CloudWatch monitors AWS resources such as Amazon EC2 and Amazon RDS DB instances, and can also monitor custom metrics generated by a customer's applications and services. With Amazon CloudWatch, you gain system-wide visibility into resource utilization, application performance, and operational health.

Amazon CloudWatch provides a reliable, scalable, and flexible monitoring solution that you can start using within minutes. You no longer need to set up, manage, or scale your own monitoring systems and infrastructure. Using Amazon CloudWatch, you can easily monitor as much or as little metric data as you need. Amazon CloudWatch lets you programmatically retrieve your monitoring data, view graphs, and set alarms to help you troubleshoot, spot trends, and take automated action based on the state of your cloud environment.

%prep
%setup -q -n CloudWatch-%{version}
for i in $(find %{_builddir} -type f); do
    if [ ! "$(file $i | grep CRLF)" = "" ]; then
        dos2unix $i
    fi
done

%build
#Released as jar files at this point, no need to build

# Make sure we don't install .cmd files
%__rm bin/*.cmd
%___build_post

%install
[ ${RPM_BUILD_ROOT} != "/" ] && %__rm -rf ${RPM_BUILD_ROOT}

# Build installation directory structure
%__mkdir_p %{buildroot}/%{aws_product_path}
%__mkdir   %{buildroot}/%{aws_product_path}/bin
%__mkdir   %{buildroot}/%{aws_product_path}/lib
%__ln_s    %{aws_product_name_v} %{buildroot}/%{aws_product_path_link}

%__mkdir_p %{buildroot}/%{aws_bin_path}

# Install all scripts in bin directory
%__install -m 755 bin/* %{buildroot}/%{aws_product_path}/bin

# Install all text files:
%__install -m 644 *.txt  %{buildroot}/%{aws_product_path}/
%__install -m 644 *.TXT  %{buildroot}/%{aws_product_path}/

# Install Java libs
%__install -m 755 lib/* %{buildroot}/%{aws_product_path}/lib

# Create sym links
for i in %{buildroot}/%{aws_product_path}/bin/*; do
    %define command_name $(basename $i)
    if [ "%{command_name}" = "service" ]; then
        continue
    fi
    %__ln_s %{aws_product_path}/bin/%{command_name} \
        %{buildroot}/%{aws_bin_path}/%{command_name}
done

# Build the environment script
echo "# Set %{aws_product_name_env}.  Called from /etc/profile.d/aws-product-common" > %{buildroot}/%{aws_product_path}/environment.sh
echo "[ -z \"\$%{aws_product_name_env}\" ] && %{aws_product_name_env}=\"%{aws_product_path_link}\"" >> %{buildroot}/%{aws_product_path}/environment.sh
echo "export %{aws_product_name_env}" >> %{buildroot}/%{aws_product_path}/environment.sh

%clean
[ ${RPM_BUILD_ROOT} != "/" ] && %__rm -rf ${RPM_BUILD_ROOT}

%files
%defattr(0644,root,root,-)
%doc %{aws_product_path}/*.txt
%doc %{aws_product_path}/*.TXT

%attr(0755,root,root) %dir %{aws_product_path}
%attr(0755,root,root) %dir %{aws_product_path}/lib

# Scripts installed with execute permission
%attr(0755,root,root) %dir %{aws_product_path}/bin
%attr(0755,root,root) %dir %{aws_bin_path}

# The sym links for easy access
%{aws_bin_path}/*
%{aws_product_path_link}

# Everything else
%{aws_product_path}/lib/*
%attr(0755,root,root) %{aws_product_path}/bin/*
%{aws_product_path}/environment.sh

%changelog
* Thu Feb 27 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.0.20.0 from upstream

* Fri Sep 21 2012 Lee Trager <ltrager@amazon.com>
- Update to 1.0.13.4 from upstream

* Mon Jun 25 2012 Lee Trager <ltrager@amazon.com>
- Search builddir for CRLF files and require dos2unix
- Convert all text files to Unix format

* Fri Jun 15 2012 Lee Trager <ltrager@amazon.com>
- Fix source directory
- These tools come as a tarball
- Clean up spec file

* Tue Aug 09 2011 Nathan Blackham <blackham@amazon.com>
- add compat libs

* Wed May 18 2011 Nathan Blackham <blackham@amazon.com>
- update to aws-apitools-mon-1.0.12.1

* Mon Feb 7 2011 Nathan Blackham <blackham@amazon.com>
- updating jre requires to >= 1.6.0

* Tue Dec 21 2010 Nathan Blackham <blackham@amazon.com>
- upgrading to 1.0.9.5

* Wed Jul 21 2010 Nathan Blackham <blackham@amazon.com>
- add dist tag

* Thu Jul 1 2010 Cristian Gafton <gafton@amazon.com>
- import source package tools/aws-apitools-mon-1.0.2.3-2
- setup complete for package aws-apitools-mon

* Tue Apr 13 2010 KaOS <kaos@amazon.com>
- Requires: jre

* Thu Feb 25 2010 KaOS <kaos@amazon.com>
- 1.0.9.0
- Initial packaging
